==> brazilian_holidays-0.1.2.tar.gz: brazilian_holidays-0.1.2/README.md <==
# Brazilian Holidays

[![Repo](https://img.shields.io/badge/GitHub-repo-blue?logo=github&logoColor=f5f5f5)](https://github.com/michelmetran/brazilian-holidays)
[![PyPI - Version](https://img.shields.io/pypi/v/brazilian-holidays?logo=pypi&label=PyPI&color=blue)](https://pypi.org/project/brazilian-holidays/)\
[![Read the Docs](https://img.shields.io/readthedocs/brazilian-holidays?logo=ReadTheDocs&label=Read%20The%20Docs)](https://brazilian-holidays.readthedocs.io/)
[![Publish Python to PyPI](https://github.com/michelmetran/brazilian-holidays/actions/workflows/publish-to-pypi.yml/badge.svg)](https://github.com/michelmetran/brazilian-holidays/actions/workflows/publish-to-pypi.yml)



<br>


> _Adoro um feriado! Quem não gosta?!_

Com objetivo de listar os feriados brasileiros, criei o pacote *
*feriados-brasileiros**, que permite criar uma tabela
contendo todos os feriados de um determinado ano, bem como ajustar atributos
conforme a necessidade.

A opção por ajustar atributos se deve ao fato de que, nem sempre, um feriado em
uma instituição também é feriado
n'outra! Feriado de endoeças, por exemplo, é feriado em instituições do meio
jurídico, enquanto muitos nem sabem que
feriado é esse!

É possível ajustar o nome dos feriados e até mesmo um campo de observações!


<br>

---

## Como Instalar?!

```shell
pip3 install brazilian-holidays
```

<br>

---

## Documentação

Para ver a documentação:

- https://brazilian-holidays.readthedocs.io

<br>

-----

## _TODO_

1. ~~Ajustar documentação~~
2. ~~Incluir o dia da semana!~~
3. ~~Implantar classe Calendário para pegar feriados de anos diversos~~
4. ~~Add domingo de ramos~~

==> brazilian_holidays-0.1.6.tar.gz: brazilian_holidays-0.1.6/README.md <==
# Brazilian Holidays

[![Repo](https://img.shields.io/badge/GitHub-repo-blue?logo=github&logoColor=f5f5f5)](https://github.com/michelmetran/brazilian-holidays)
[![PyPI - Version](https://img.shields.io/pypi/v/brazilian-holidays?logo=pypi&label=PyPI&color=blue)](https://pypi.org/project/brazilian-holidays/)\
[![Read the Docs](https://img.shields.io/readthedocs/brazilian-holidays?logo=ReadTheDocs&label=Read%20The%20Docs)](https://brazilian-holidays.readthedocs.io/)
[![Publish Python to PyPI](https://github.com/michelmetran/brazilian-holidays/actions/workflows/publish-to-pypipoetry.yml/badge.svg)](https://github.com/michelmetran/brazilian-holidays/actions/workflows/publish-to-pypipoetry.yml)

<br>

> _Adoro um feriado! Quem não gosta?!_

Com objetivo de listar os feriados brasileiros, criei o pacote \*
\*feriados-brasileiros\*\*, que permite criar uma tabela
contendo todos os feriados de um determinado ano, bem como ajustar atributos
conforme a necessidade.

A opção por ajustar atributos se deve ao fato de que, nem sempre, um feriado em
uma instituição também é feriado
n'outra! Feriado de endoeças, por exemplo, é feriado em instituições do meio
jurídico, enquanto muitos nem sabem que
feriado é esse!

É possível ajustar o nome dos feriados e até mesmo um campo de observações!

<br>

---

## Como Instalar?!

```shell
pip3 install brazilian-holidays
```

<br>

---

## Documentação

Para ver a documentação:

- https://brazilian-holidays.readthedocs.io

<br>

---

## _TODO_

1. ~~Ajustar documentação~~
2. ~~Incluir o dia da semana!~~
3. ~~Implantar classe Calendário para pegar feriados de anos diversos~~
4. ~~Add domingo de ramos~~
